import { Component } from '../core/component';
import { VNode, VNodeTag, Props, TransitionHooks, TransitionElement, VNodeComponentClass, NormalizedChildren } from 'misstime';
export declare type BaseTransitionCallback = (el: TransitionElement) => void;
export declare type BaseTransitionDoneCallback = (el: TransitionElement, done: () => void) => void;
export interface BaseTransitionProps {
    appear?: boolean;
    show?: boolean;
    onBeforeEnter?: BaseTransitionCallback;
    onEnter?: BaseTransitionDoneCallback;
    onAfterEnter?: BaseTransitionCallback;
    onEnterCancelled?: BaseTransitionCallback;
    onBeforeLeave?: BaseTransitionCallback;
    onLeave?: BaseTransitionDoneCallback;
    onAfterLeave?: BaseTransitionCallback;
    onLeaveCancelled?: BaseTransitionCallback;
    onBeforeAppear?: BaseTransitionCallback;
    onAppear?: BaseTransitionDoneCallback;
    onAfterAppear?: BaseTransitionCallback;
    onAppearCancelled?: BaseTransitionCallback;
}
export declare class BaseTransition<P extends BaseTransitionProps = BaseTransitionProps> extends Component<P> {
    static template(this: BaseTransition): VNode<VNodeTag> | null;
    static defaults(): Partial<BaseTransitionProps>;
    leavingVNodesCache: Record<string, VNode>;
    el: TransitionElement | null;
    originalDisplay: string;
    mounted(): void;
    updated(lastVNode: VNodeComponentClass<BaseTransition<P>>, nextVNode: VNodeComponentClass<BaseTransition<P>>): void;
    unmounted(): void;
}
export declare function resolveTransitionHooks(vNode: VNode, props: Props<BaseTransitionProps, BaseTransition>, component: BaseTransition, isTransitionGroup: boolean): TransitionHooks;
export declare function setTransitionHooks(vNode: VNode, hooks: TransitionHooks): void;
export declare function isInvalidTranstionChild(vNode: NormalizedChildren): number | true;
