import { ComponentClass, Props, VNodeComponentClass, IntactDom, VNode, TypeDefs } from 'misstime';
import { SetOptions, InjectionKey, LifecycleEvents } from '../utils/types';
import { Event } from './event';
import { Template } from 'vdt';
import { WatchOptions } from './watch';
export declare let currentInstance: Component<any> | null;
export declare function useInstance(): Component<any, {}, {}, {}> | null;
export declare function setInstance(instance: Component<any> | null): void;
declare type NoInfer<T> = [T][T extends any ? 0 : never];
export declare abstract class Component<P extends {} = {}, E extends {} = {}, B extends {} = {}, S extends {} = {}> extends Event<P, E, LifecycleEvents<Component<P, E>>> implements ComponentClass<P> {
    static readonly template: Template | string;
    static readonly defaults: () => object;
    static readonly typeDefs?: TypeDefs<any>;
    static readonly displayName?: string;
    refs: Record<string, any>;
    $props: Props<P, this>;
    $SVG: boolean;
    $vNode: VNodeComponentClass<this>;
    $senior: Component<any> | null;
    $mountedQueue: Function[];
    $lastInput: VNode | null;
    $blockRender: boolean;
    $queue: Function[] | null;
    $pendingQueue: Function[] | null;
    $provides: Record<InjectionKey, any> | null;
    $uid: number;
    $inited: boolean;
    $rendered: boolean;
    $mounted: boolean;
    $unmounted: boolean;
    $template: Template;
    private triggerReceiveEvents;
    constructor(props: Props<P, Component<P>> | null | undefined, $vNode: VNodeComponentClass, $SVG: boolean, $mountedQueue: Function[], $senior: ComponentClass | null);
    $init(props: Props<P, this> | null): void;
    $render(lastVNode: VNodeComponentClass<this> | null, nextVNode: VNodeComponentClass<this>, parentDom: Element, anchor: IntactDom | null, mountedQueue: Function[]): void;
    $mount(lastVNode: VNodeComponentClass<this> | null, nextVNode: VNodeComponentClass<this>): void;
    $update(lastVNode: VNodeComponentClass<this>, nextVNode: VNodeComponentClass<this>, parentDom: Element, anchor: IntactDom | null, mountedQueue: Function[], force: boolean): void;
    $unmount(vNode: VNodeComponentClass<this>, nextVNode: VNodeComponentClass<this> | null): void;
    init?(props: Props<P, Component<P>> | null | undefined): any;
    beforeMount?(lastVNode: VNodeComponentClass | null, nextVNode: VNodeComponentClass): void;
    mounted?(lastVNode: VNodeComponentClass | null, nextVNode: VNodeComponentClass): void;
    beforeUpdate?(lastVNode: VNodeComponentClass, nextVNode: VNodeComponentClass): void;
    updated?(lastVNode: VNodeComponentClass, nextVNode: VNodeComponentClass): void;
    beforeUnmount?(vNode: VNodeComponentClass, nextVNode: VNodeComponentClass | null): void;
    unmounted?(vNode: VNodeComponentClass, nextVNode: VNodeComponentClass | null): void;
    set<K extends keyof P>(key: K, value: P[K], options?: SetOptions): void;
    set<T, K extends keyof T = keyof T>(key: K, value: T[K], options?: SetOptions): void;
    set<T = void>(key: string, value: NoInfer<T>, options?: SetOptions): void;
    set<K extends keyof P>(data: Pick<P, K>, options?: SetOptions): void;
    set<T = void>(data: Partial<P> & NoInfer<T>, options?: SetOptions): void;
    set<T = void>(data: NoInfer<T>, options?: SetOptions): void;
    get(): Props<P, this>;
    get<K extends keyof Props<P, this>>(key: K): Props<P, this>[K];
    get<V = void>(key: V extends void ? never : string): V;
    forceUpdate(callback?: Function): void;
    trigger<K extends keyof E>(name: K, ...args: any[] & E[K]): void;
    watch<K extends keyof Props<P, this>>(key: K, callback: (newValue: Props<P, this>[K], oldValue: Props<P, this>[K] | undefined) => void, options?: WatchOptions): void;
}
export {};
